<!-- <p align='center'><a href="https://ydcjeff.github.io/clifold" target="_blank" rel="noopener noreferrer"></p> -->

![clifold logo](./docs/Clifold.svg)

<h1 align='center'>Clifold</h1>

[![Build Status](https://travis-ci.com/ydcjeff/clifold.svg?token=Hh6ZhQhxWHRigNVJeYyv&branch=master)](https://travis-ci.com/ydcjeff/clifold)  ![Python package](https://github.com/ydcjeff/clifold/workflows/Python%20package/badge.svg?branch=master)

## Usage:
```
usage: clif <arg> [options]

🚀 A CLI tool for scaffolding any Python Projects 🚀

Argument:
  project_name    Project name to create with venv

Options:
  -g, --git       Make git initialization
  -ng, --no-git   Skip git initialization
  -p, --pkg       Ask packages to install
  -np, --no-pkg   Skip packages installation
  -i, --init      Create setup.py file
  -ni, --no-init  Skip setup.py file
  -V, --version   Output version number
  -h, --help      Output usage information
```